@@ -1,5 +1,5 @@
 package CPAN::Upload::Tiny;
-$CPAN::Upload::Tiny::VERSION = '0.002';
+$CPAN::Upload::Tiny::VERSION = '0.003';
 use strict;
 use warnings;
 
@@ -69,9 +69,10 @@ sub read_config_file {
 
 			next if not length or $_ =~ /^\s*#/;
 
-			my ($k, $v) = / ^ \s* (user|password) \s+ (.+?) \s* $ /x;
-			Carp::croak "Multiple enties for $k" if $conf{$k};
-			$conf{$k} = $v;
+			if (my ($k, $v) = / ^ \s* (user|password) \s+ (.+?) \s* $ /x) {
+				Carp::croak "Multiple enties for $k" if $conf{$k};
+				$conf{$k} = $v;
+			}
 		}
 	}
 	Carp::croak('No user set in configuration file')     if not $conf{user};
@@ -96,7 +97,7 @@ CPAN::Upload::Tiny - A tiny CPAN uploader
 
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =head1 SYNOPSIS
 
